@@ -17,6 +17,8 @@ class RedisServerAdmin(admin.ModelAdmin):
     list_display = (
         '__unicode__', 'status', 'memory', 'clients', 'details', 'tools'
     )
+    list_filter = 'label', 'hostname'
+    ordering = ('hostname', 'port')
     def status(self, obj):
         return obj.stats['status']
     status.long_description = _("Status")
@@ -47,8 +49,11 @@ class RedisServerAdmin(admin.ModelAdmin):
 
     def get_urls(self):
         urlpatterns = super(RedisServerAdmin, self).get_urls()
-        from django.conf.urls.defaults import patterns, url
-
+        try:
+            from django.conf.urls import patterns, url
+        except ImportError:
+            from django.conf.urls.defaults import patterns, url
+    
         def wrap(view):
             def wrapper(*args, **kwargs):
                 return self.admin_site.admin_view(view)(*args, **kwargs)
