@@ -13,10 +13,9 @@ from .utils import cached_property
 
 REDISBOARD_DETAIL_FILTERS = [re.compile(name) for name in getattr(settings, 'REDISBOARD_DETAIL_FILTERS', (
     'aof_enabled', 'bgrewriteaof_in_progress', 'bgsave_in_progress',
-    'changes_since_last_save', 'db.*', 'db1', 'last_save_time',
-    'multiplexing_api', 'total_commands_processed',
-    'total_connections_received', 'uptime_in_days', 'uptime_in_seconds',
-    'vm_enabled', 'redis_version'
+    'changes_since_last_save', 'db.*', 'last_save_time', 'multiplexing_api',
+    'total_commands_processed', 'total_connections_received', 'uptime_in_days',
+    'uptime_in_seconds', 'vm_enabled', 'redis_version'
 ))]
 REDISBOARD_DETAIL_TIMESTAMP_KEYS = getattr(settings, 'REDISBOARD_DETAIL_TIMESTAMP_KEYS', (
     'last_save_time',
@@ -42,13 +41,36 @@ class RedisServer(models.Model):
             ("can_inspect", "Can inspect redis servers"),
         )
 
-    hostname = models.CharField(_("Hostname"), max_length=250, help_text=_('this can also be the absolute path to a redis socket'))
+    label = models.CharField(
+        _('Label'),
+        max_length = 50,
+        blank = True,
+        null = True,
+    )
+
+    hostname = models.CharField(
+        _("Hostname"),
+        max_length = 250,
+        help_text = _('This can also be the absolute path to a redis socket')
+    )
+
     port = models.IntegerField(_("Port"), validators=[
         MaxValueValidator(65535), MinValueValidator(1)
     ], default=6379, blank=True, null=True)
     password = models.CharField(_("Password"), max_length=250,
                                 null=True, blank=True)
 
+    sampling_threshold = models.IntegerField(
+        _("Sampling threshold"),
+        default = 1000,
+        help_text = _("Number of keys after which only a sample (of random keys) is shown on the inspect page.")
+    )
+    sampling_size = models.IntegerField(
+        _("Sampling size"),
+        default = 200,
+        help_text = _("Number of random keys shown when sampling is used. Note that each key translates to a RANDOMKEY call in redis.")
+    )
+
     def clean(self):
         if not self.hostname.startswith('/') and not self.port:
             raise ValidationError(_('Please provide either a hostname AND a port or the path to a redis socket'))
@@ -110,6 +132,14 @@ class RedisServer(models.Model):
 
 
     def __unicode__(self):
+        if self.label:
+            label = '%s (%%s)' % self.label
+        else:
+            label = '%s'
+
         if self.port:
-            return "%s:%s" % (self.hostname, self.port)
-        return self.hostname
+            label = label % ('%s:%s' % (self.hostname, self.port))
+        else:
+            label = label % self.hostname
+
+        return label
